# capiq_excel

## Overview

Use this tool to drive Excel using the Capital IQ plugin to download Capital IQ data. 

## Links

See the example 
[generated documentation here.](
https://whoopnip.github.io/capiq-excel-downloader-py/
)
